function m0322
%  m0322.m     (Matlab&Simulink Rel.14 SP3)
%
%  Bild 3.22 
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme: s0322.mdl
%
%  (c)10.11.05  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%   schalt    Umschalter fr die grafische Ausgabe:
%              schalt=0        nur "gemessene" Sprungantwort (S)
%              schalt=1        (S) mit I-Tn-Modell
%              schalt=2        (S) mit I-T1-Tt-Modell
%              schalt=3        (S) mit beiden Modellen
%    
%   ydach     Sprunghhe der Stellgre, 0<ydach<1.5
%
%   Aus "gemessener" Sprungantwort (schalt=0) ablesen:
%   (Ausdrucken mit "File" und "Print" im Grafik-Fenster)
%   Kis       Proportionalbeiwert der Strecke
%   Tu        Verzugszeit
%   xu        x an der Stelle Tu
%
%   I-Tn-Modell (rot):
%   n         Modellordnung (Bild 3.24a ermitteln)
%   T1        Zeitkonstante (Bild 3.24b ermitteln)
%
%   I-T1-Tt-Modell (blau)
%   Tt        Totzeit, 0 < Tt < Tu
%
% ########################################################
clear
    schalt=3;        % schalt=3
    
    ydach=1.;        % ydach=1
    
    Kis=.6;          % Kis=1    
    Tu=1.8;          % Tu=1.8
    
    n=4;             % n=4
    T1=.45;          % T1=0.45
    
    Tt=.8;            % Tt=.8
     
% ########################################################

close all
fonts=8;

s=tf('s');


% Modelldaten
% I-Tn  (Kis, n, T1)
G=Kis/s/(T1*s+1)^n;
ITnzae=cell2mat(G.num);
ITnnen=cell2mat(G.den);
assignin('base','ITnzae',ITnzae)
assignin('base','ITnnen',ITnnen)


% I-T1-Tt
T1=Tu-Tt;        
assignin('base','Kis',Kis)
assignin('base','T1',T1)
assignin('base','Tt',Tt)


% "Gemessene" Sprungantwort
%  einer nichtschwingenden Strecke ohne Ausgleich
 T1=.1;           % T1=.1
 T2=.2;           % T1=.2
 T3=.6;           % T1=.6
G=Kis/s/(T1*s+1)^2/(T2*s+1)^2/(T3*s+1)^2;
num=cell2mat(G.num);
den=cell2mat(G.den);
assignin('base','zae',num)
assignin('base','nen',den)



% Sprunghhe fr reale Strecke und Streckenmodelle
assignin('base','ydach',ydach)

% Integrationsschleife:
te=8;

figure(1)
set(gcf,'Units','normal','Position',[.65 .3 .3 .5], ...
    'NumberTitle','off','MenuBar','fig',...
    'Name',' Bild 3.22 Strecke o. Ausgl. mit Verzg.');
buch(gcf)

sp21=subplot(2,1,1);
set(gca,'FontSize',fonts,...
    'XLim',[-.5 te],...
    'XTick',[0:1:20],...
    'XGrid','off',...
    'YLim',[0 1.5],...
    'YTick',[0:.2:2],...
    'YGrid','off',...
    'NextPlot','add',...
    'Box','on');
tachs1=[0 te]; tachs2=[0 0];
yachs1=[0 0]; yachs2=[-2 2];
plot(tachs1,tachs2,'k',yachs1,yachs2,'k')
tGGx=[-1 0]; tGGy=[0 0];
plot(tGGx,tGGy,'k','linewidth',1.5)
xlabel('t  \rightarrow')
ylabel('y  \rightarrow')


sp22=subplot(2,1,2);
set(gca,'FontSize',fonts,...
    'XLim',[-.5 te],...
    'XTick',[0:.5:20],...
    'XGrid','on',...
    'YLim',[0 3],...
    'YTick',[0:.2:3],...
    'YGrid','on',...
    'NextPlot','add',...
    'Box','on');
tachs1=[-.5 te]; tachs2=[0 0];
yachs1=[0 0]; yachs2=[-2 20];
plot(tachs1,tachs2,'k',yachs1,yachs2,'k')
tGGx=[-1 0]; tGGy=[0 0];
plot(tGGx,tGGy,'k','linewidth',1.5)
xlabel('t  \rightarrow')
ylabel('x  \rightarrow')



opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',.1);
[t,x,y]=sim('s0322',[0 te],opts);


figure(1)
axes(sp21)
ysprungx=[0 0];
if ydach>0
    ysprungy=[0 ydach];
else
    ysprungy=[ydach 0];
end
plot(ysprungx,ysprungy,'k','linewidth',1.5)
plot(t,y(:,1),'k-','linewidth',1.5)    %  y


axes(sp22)
if schalt==0
plot(t,y(:,2),'k-','linewidth',1)    %  x
end

if schalt==1
    plot(t,y(:,2),'k-','linewidth',1)
    hold on
    plot(t,y(:,3),'r-','linewidth',1)
end


if schalt==2
    plot(t,y(:,2),'k-','linewidth',1)
    hold on
    plot(t,y(:,4),'b-','linewidth',1)
end


if schalt==3
    plot(t,y(:,2),'k-','linewidth',1)
    hold on
    plot(t,y(:,3),'r-','linewidth',1)
plot(t,y(:,4),'b-','linewidth',1)
end




















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?')
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep')
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik')
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')

