function m0511
%  m0511.m     (Matlab&Simulink Rel.14 SP3)
%
%  Bild 5.11 a und b
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme:  keine
%
%  (c)10.11.05  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%  Frequenzwerte auf den Ortskurven bzw. im Bode-Diagramm 
%      im Bereich von   0.01  <  omega  <  1 
%
%    Es knnen auch mehrere Werte  omega1, omega2, ...
%    vorgegeben werden im Vektor 
%                            wpar=[ omega1 omega2 ... ]
%
% ########################################################
clear

   wpar=[ .01  .1  1. ];  % Voreinstellung wpar=[.01 .1 1.] 

% ########################################################

menu='none';  % none oder fig
close all
fonts=8; 


% Offener Kreis
%  Nr.1:
Kps1=2.5; Ts1=5; Tt1=8;
ozae1=[Kps1];
onen1x=[Ts1  1];
onen1=conv(onen1x,onen1x);
onen1=conv(onen1,onen1x);
[tzae,tnen]=pade(Tt1,3); 
ozae1=conv(ozae1,tzae);
onen1=conv(onen1,tnen);

%  Nr.2:
Kps2=1.5; Ts2=Ts1; Tt2=Tt1;
ozae2=[Kps2];
onen2x=[Ts2  1];
onen2=conv(onen2x,onen2x);
onen2=conv(onen2,onen2x);
[tzae,tnen]=pade(Tt2,3); 
ozae2=conv(ozae2,tzae);
onen2=conv(onen2,tnen);


% Ortskurven
figure(1)
set(gcf,'Units','normal','Position',[.53 .53 .45 .4], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 5.11a: Ortskurven');
buch(gcf)

re1=[-1.5 2.5]; re2=[ 0 0];
im1=[0 0]; im2=[ -2.5 1.5];
plot(re1,re2,'k',im1,im2,'k');
grid on, hold on
set(gca,'FontSize',fonts, ...
    'Position',[.1 .15 .8 .8],...
    'XTick',[-1:2],'YTick',[-2:1]);
axis([-1.5 2.5 -2.5 1.5])
axis square
xlabel('Re\{Go\} \rightarrow')
ylabel('Im\{Go\} \rightarrow')

w=logspace(-4,2,600);      %  Ortskurven
[re1,im1,w]=nyquist(ozae1,onen1,w);
[re2,im2,w]=nyquist(ozae2,onen2,w);
plot(re1,im1,'g',re2,im2,'g--')

incr=0:.1:2*pi;            % Einheitskreis
x=sin(incr); y=cos(incr);
plot(x,y,'k');

% Parametrierung
[re1,im1,wpar]=nyquist(ozae1,onen1,wpar);
[re2,im2,wpar]=nyquist(ozae2,onen2,wpar);
plot(re1,im1,'r.',re2,im2,'r.','MarkerSize',12); 
wparstring=num2str(wpar);
text(re1,im1,wparstring,'VerticalAlign','bottom',...
    'HorizontalAlignment','right','fonts',8)
text(re2,im2,wparstring,'VerticalAlign','bottom',...
    'HorizontalAlignment','right','fonts',8)


% Frequenzgang im Bode-Diagramm
figure(2)
set(gcf,'Units','normal','Position',[.53 .05 .45 .4], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 5.11b: Bode-Diagramme');
buch(gcf)

dBachs=[-2,-1,0,1,2]*10;
phachs=[-5,-4,-3,-2,-1,0,1,2,3,4,5]*90;

w=logspace(-2,0,500);  %  Frequenzachse

[betr1,phas1,w]=bode(ozae1,onen1,w);
[betr2,phas2,w]=bode(ozae2,onen2,w);

subplot(2,1,1)
betr1=20*log10(betr1);
betr2=20*log10(betr2);
semilogx(w,betr1,'g',w,betr2,'g--')
grid on; hold on
set(gca,'FontSize',fonts,'YTick',dBachs)
axis([0.01 1 -10 10])
db1=[.01 1]; db2=[ 0 0 ];
semilogx(db1,db2,'k')
xlabel('\omega/(rad/s) \rightarrow','fonts',8)
ylabel('|G_O|_{dB} \rightarrow')

subplot(2,1,2)
semilogx(w,phas1,'g',w,phas2,'g--'); grid on; hold on
set(gca,'FontSize',fonts,'YTick',phachs);
axis([0.01 1 -270 0])
grd1=[.01 1]; grd2=[ -180 -180 ];
semilogx(grd1,grd2,'k')
xlabel('w  (rad/s)')
ylabel('/Go')
xlabel('\omega/(rad/s) \rightarrow','fonts',8)
ylabel('/G_O \rightarrow')

% Parametrierung
[betr1,phas1,w]=bode(ozae1,onen1,wpar);
[betr2,phas2,w]=bode(ozae2,onen2,wpar);

subplot(2,1,1)
betr1=20*log10(betr1);
betr2=20*log10(betr2);
plot(wpar,betr1,'r.',wpar,betr2,'r.','Markers',12)
wparstring=num2str(wpar);
text(wpar,betr1,wparstring,'VerticalAlign','bottom',...
    'HorizontalAlignment','left','fonts',8)
text(wpar,betr2,wparstring,'VerticalAlign','bottom',...
    'HorizontalAlignment','left','fonts',8)

subplot(2,1,2)
plot(wpar,phas1,'r.',wpar,phas2,'r.','Markers',12)
wparstring=num2str(wpar);
text(wpar,phas1,wparstring,'VerticalAlign','bottom',...
    'HorizontalAlignment','left','fonts',8)























function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')


