function m0524
%  m0524.m     (Matlab&Simulink Rel.14 SP3)
%
%  Bild 5.24 a und b
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme:  s0524.mdl
%
%  (c)10.11.05  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%    Reglerverstrkung  Kpr  im Bereich  0.1 < Kpr < 16
%
%  Vernderung des erlaubten Polgebietes:
%    Dmpfungsgrad     d  im Bereich 0.0 < d  <  0.99.
%    Kennkreisfrequenz omega0 im Bereich 0 < omega0 < 4
%
% ########################################################
clear

      Kpr=4.16;       % Voreinstellung Kpr=4.16

      d=.7;           % Voreinstellung d=0.7
      omega0=3;       % Voreinstellung omega0=3;

% ########################################################

menu='none';  % none oder fig
close all
fonts=8;  

% Offener Kreis
%---------------------------------------------
% Strecke:
Kps=0.2; T1S=0.8; T2S=sqrt(0.2);
szae=[Kps];
snen=[T2S^2 T1S  1];

% Regler 
Tv=0.33;  T1R=0.25;
rzae=[Tv  1]; 
rnen=[T1R 1]; 

% Offener Kreis:
ozae=conv(rzae,szae);
onen=conv(rnen,snen);


% WOK
%---------------------------------------------

figure(1)
set(gcf,'Units','normal','Position',[.5 .5 .45 .44], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 5.24a');
buch(gcf)

re1=[-5 1]; re2=[0 0]; im1=[0 0]; im2=[-5 5]; 
plot(re1,re2,'k',im1,im2,'k')
grid on;  hold on
reachs=[-5:1:5]; imachs=[-5:1:5];
set(gca,'FontSize',fonts,...
    'DataAspectRatio',[1 1 1],...
    'XTick',imachs,'YTick',reachs);
axis([-5 1 -5 5])
xlabel('Re\{s\} \rightarrow')
ylabel('Im\{s\} \rightarrow')

[r,k]=rlocus(ozae,onen);     %  WOK berechnen
plot(r,'c-','LineW',1)       %  WOK plotten

p=roots(onen);               % Pole
z=roots(ozae);               % Nullstellen
plot(real(p),imag(p),'cx',real(z),imag(z),'co',...
    'LineW',2) 

% Pole fr gegebenes Kpr einzeichnen:
[rparam,Kpr]=rlocus(ozae,onen,Kpr);
plot(rparam,'rx','LineW',2);
s1=' Rot: Pole des Regelkreises fr Kpr=';
title([s1,num2str(Kpr)])

% Erlaubtes Polgebiet
dstr=sqrt(1-d^2); omegae=omega0*dstr;
sigma=-omega0*d;

incr=pi:.1:2*pi;         
x=omega0*sin(incr); y=omega0*cos(incr);
plot(x,y,'k')

x=[-5:.1:0]; y=-abs(omegae/sigma)*x;
plot(x,y,'k')
x=[-5:.1:0]; y=abs(omegae/sigma)*x;
plot(x,y,'k')


% Zeitverhalten
%---------------------------------------------
%  Vorfilter:
Kv=(1+Kps*Kpr)/(Kps*Kpr);      % Damit eb=0

figure(2)
set(gcf,'Units','normal','Position',[.5 .07 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 5.24b');
buch(gcf)

wdach=1;
tstep=0.001;  
te=3.5;

% bertragen in basic workspace
assignin('base','wdach',wdach)
assignin('base','tstep',tstep)
assignin('base','Kv',Kv)
assignin('base','Kpr',Kpr)
assignin('base','rzae',rzae)
assignin('base','rnen',rnen)
assignin('base','szae',szae)
assignin('base','snen',snen)

opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',.01);

[t,x,y]=sim('s0524',[0 te],opts);

tachs1=[-0.5 te]; tachs2=[0 0]; 
xachs1=[ 0 0]; xachs2=[-0.2 1.5];
plot(tachs1,tachs2,'k',xachs1,xachs2,'k')
grid on, hold on
set(gca,'FontSize',fonts,...
    'Position',[.15 .17 .75 .7]);
axis([-.5 te -.2 1.5]); 
xlabel('t \rightarrow')
ylabel('x , w \rightarrow')

plot(t,y(:,1),'r','LineW',2) 
plot(t,y(:,2)) 

eps=0.05;  
wtolob=wdach+eps; wtovec=[wtolob wtolob];
wtolun=wdach-eps; wtuvec=[wtolun wtolun];
zeit=[0 te];
plot(zeit,wtovec,'m',zeit,wtuvec,'m')

s1=' Rot: Fhrungssprungantwort fr Kpr=';
title([s1,num2str(Kpr)])





















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')


