function m0707
%  m0707.m     (Matlab&Simulink Rel.14 SP3)
%
%  Bild 7.7 a und b
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme:  s0706_1.mdl, s0706_2.mdl, 
%                   s0706_3.mdl, s0706_4.mdl
%
%  (c)10.11.05  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%    Abtastperiode   T     im Bereich 10.   <  T    < 100.
%
%  Sprungantwort (Bild 7.7a):
%    Sprunghhe     udach  im Bereich  5.   < udach < 10.
%
%  Schwingungsantwort (Bild 7.7b):
%    Amplitude      udach  im Bereich  5.   < udach < 10.
%    Kreisfrequenz  om0    im Bereich .0001 < om0 < 0.001.
%
% ########################################################
clear

     T=40;           %  Voreinstellung T=40

     udach=10;       %  Voreinstellung udach=10

     om0=.0001;      %  Voreinstellung om0=0.0001

% ########################################################

menu='none';  % none oder fig
close all
fonts=8;


% Temperaturstrecke

% Analoges Modell:
KPS=.2; wo=.03; d=2;     
zae=[KPS*wo^2]; 
nen=[1 2*d*wo wo^2];  

% Digitales Modell:
dstr=sqrt(d^2-1); 
s1=-wo*(d+dstr); s2=-wo*(d-dstr);
alf1=exp(s1*T); alf2=exp(s2*T);
A1=(d-dstr)/(2*dstr);
A2=-(d+dstr)/(2*dstr);
A3=1;

b0=0;  % Formeln gem Buch S. 248 oben  
b1=KPS*(1+1/(2*dstr)*((d-dstr)*alf1-(d+dstr)*alf2));
b2=KPS*(alf1*alf2+1/(2*dstr)*((d-dstr)*alf2-(d+dstr)*alf1));
a1=-(alf1+alf2);
a2=alf1*alf2;

zaed=[b0 b1 b2]; nend=[1  a1  a2];


% In Workspace ablegen (fr Simulink)
assignin('base','T',T)
assignin('base','udach',udach)
assignin('base','om0',om0)
assignin('base','zae',zae)
assignin('base','nen',nen)
assignin('base','zaed',zaed)
assignin('base','nend',nend)


figure(1)
set(gcf,'Units','normal','Position',[.53 .6 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 7.7a'); 
buch(gcf)  

te=520; 

opts=simset('Solver','ode45',...
    'InitialState',[0 0],...
    'MaxStep',10.);
[t1,x1,y1]=sim('s0706_1',[0 te],opts);

opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[0 0],...
    'FixedStep',T);
[t2,x2,y2]=sim('s0706_2',[0 te],opts);

subplot(2,1,1)
plot(t1,y1(:,1),'g'),grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -2 15]); 
plot(t2,y2(:,1),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
title('Grn: Analoges Modell, Blau: Digitales Modell')
ylabel('y')

subplot(2,1,2)
plot(t1,y1(:,2),'g'), grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -.5 2.5]); 
plot(t2,y2(:,2),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
ylabel('x')


figure(2)
set(gcf,'Units','normal','Position',[.53 .1 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 7.7b'); 
buch(gcf)  

opts=simset('Solver','ode45',...
    'InitialState',[0 0],...
    'MaxStep',1.);
[t1,x1,y1]=sim('s0706_3',[0 te],opts);

opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[0 0],...
    'FixedStep',T);
[t2,x2,y2]=sim('s0706_4',[0 te],opts);

subplot(2,1,1)
plot(t1,y1(:,1),'g'),grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -12 12]); 
plot(t2,y2(:,1),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
title('Grn: Analoges Modell, Blau: Digitales Modell')
ylabel('y')

subplot(2,1,2)
plot(t1,y1(:,2),'g'), grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -1.5 2.5]); 
plot(t2,y2(:,2),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
ylabel('x')



















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')
