function m0709
%  m0709.m     (Matlab&Simulink Rel.14 SP3)
%
%  Bild 7.9
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme:  s0706_1.mdl, s0706_2.mdl, 
%                   s0706_3.mdl, s0706_4.mdl
%
%  (c)10.11.05  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%    Abtastperiode   T     im Bereich 10    <  T    < 30.
%
%  Sprungantwort (Bild 7.9):
%    Sprunghhe     udach  im Bereich .5    < udach < 1.
%
%  Schwingungsantwort (entsprechend Bild 7.6b):
%    Amplitude      udach  im Bereich .5    < udach < 1.
%    Kreisfrequenz  om0    im Bereich 300.  < om0  < 800.
%
% ########################################################
clear

     T=0.02;         %  Voreinstellung T=.02

     udach=1;        %  Voreinstellung udach=1

     om0=300;        %  Voreinstellung 0m0=500

% ########################################################

menu='none';  % none oder fig
close all
fonts=8;


% Gleichstrommotor:

% Analoges Modell:
J=.001;     % Nm/(rad/s^2)=Nms^2, Trgheitsmom.
cR=0.01;    % Nm/(rad/s)=Nms, Reibung
KIS=1/cR; T1=J/cR;    

zae=[KIS]; nen=[T1 1 0];

% Digitales Modell:  (Formeln auf S.251)
alf=exp(-T/T1);
b0=0;
b1=KIS*(-(1-alf)*T1 + T);
b2=KIS*((1-alf)*T1 - alf*T);
a1=-(1+alf);
a2=alf;

zaed=[b0 b1 b2]; nend=[1  a1  a2];


% In Workspace ablegen (fr Simulink)
assignin('base','T',T)
assignin('base','udach',udach)
assignin('base','om0',om0)
assignin('base','zae',zae)
assignin('base','nen',nen)
assignin('base','zaed',zaed)
assignin('base','nend',nend)



figure(1)
set(gcf,'Units','normal','Position',[.53 .6 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 7.9'); 
buch(gcf)  

te=.4; 

opts=simset('Solver','ode45',...
    'InitialState',[0 0],...
    'MaxStep',0.01);
[t1,x1,y1]=sim('s0706_1',[0 te],opts);

opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[0 0],...
    'FixedStep',T);
[t2,x2,y2]=sim('s0706_2',[0 te],opts);

subplot(2,1,1)
plot(t1,y1(:,1),'g'),grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -.5 1.5]); 
plot(t2,y2(:,1),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
title('Grn: Analoges Modell, Blau: Digitales Modell')
ylabel('y')

subplot(2,1,2)
plot(t1,y1(:,2),'g'), grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -5 30]); 
plot(t2,y2(:,2),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
ylabel('x')


figure(2)
set(gcf,'Units','normal','Position',[.53 .1 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Zu Bild 7.9: Schwingungsanregung'); 
buch(gcf)  

opts=simset('Solver','ode45',...
    'InitialState',[0 0],...
    'MaxStep',0.001);
[t1,x1,y1]=sim('s0706_3',[0 te],opts);

opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[0 0],...
    'FixedStep',T);
[t2,x2,y2]=sim('s0706_4',[0 te],opts);

subplot(2,1,1)
plot(t1,y1(:,1),'g'),grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -1.2 1.2]); 
plot(t2,y2(:,1),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
title('Grn: Analoges Modell, Blau: Digitales Modell')
ylabel('y')

subplot(2,1,2)
plot(t1,y1(:,2),'g'), grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -5 30]); 
plot(t2,y2(:,2),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
ylabel('x')




















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')




